@@ -17,13 +17,13 @@ QMainWindow(parent, Qt::FramelessWindowHint),
     ui->centralWidget->setPalette(palette);
     QSettings settings;
     if (!settings.contains(PCW_SETTING_WIDTH))
-        settings.setValue(PCW_SETTING_WIDTH, 72);
+        settings.setValue(PCW_SETTING_WIDTH, PCW_SETTING_WIDTH_DEFAULT);
     if (!settings.contains(PCW_SETTING_HEIGHT))
-        settings.setValue(PCW_SETTING_HEIGHT, 72);
+        settings.setValue(PCW_SETTING_HEIGHT, PCW_SETTING_HEIGHT_DEFAULT);
     if (!settings.contains(PCW_SETTING_OPACITY))
-        settings.setValue(PCW_SETTING_OPACITY, 70);
+        settings.setValue(PCW_SETTING_OPACITY, PCW_SETTING_OPACITY_DEFAULT);
     if (!settings.contains(PCW_SETTING_SHOWNEXTPROFILE))
-        settings.setValue(PCW_SETTING_SHOWNEXTPROFILE, true);
+        settings.setValue(PCW_SETTING_SHOWNEXTPROFILE, PCW_SETTING_SHOWNEXTPROFILE_DEFAULT);
     if (!settings.contains(PCW_SETTING_LASTVERSION))
         settings.setValue(PCW_SETTING_LASTVERSION, PCW_SETTING_LASTVERSION_DEFAULT);
 
@@ -112,7 +112,6 @@ void ProfileChangerWidget::onShowSettingsDialog()
     SettingsDialog *dialog = new SettingsDialog(0);
     connect(dialog, SIGNAL(settingsChanged()), this, SLOT(reloadSettings()));
     dialog->show();
-    dialog->checkVersion();
 }
 
 void ProfileChangerWidget::onHomeScreenChanged(bool isOnCurrentHomescreen)
@@ -124,19 +123,19 @@ void ProfileChangerWidget::onHomeScreenChanged(bool isOnCurrentHomescreen)
 void ProfileChangerWidget::reloadSettings()
 {
     QSettings settings;
-    this->showNextProfile = settings.value(PCW_SETTING_SHOWNEXTPROFILE).toBool();
+    this->showNextProfile = settings.value(PCW_SETTING_SHOWNEXTPROFILE, PCW_SETTING_SHOWNEXTPROFILE_DEFAULT).toBool();
     this->setGeometry(this->x(), this->y(),
-                      settings.value(PCW_SETTING_WIDTH).toInt(),
-                      settings.value(PCW_SETTING_HEIGHT).toInt());
-    ui->switchButton->setStyleSheet("background-color: rgba(0, 0, 0, " + settings.value(PCW_SETTING_OPACITY).toString() + "%); \
+                      settings.value(PCW_SETTING_WIDTH, PCW_SETTING_WIDTH_DEFAULT).toInt(),
+                      settings.value(PCW_SETTING_HEIGHT, PCW_SETTING_HEIGHT_DEFAULT).toInt());
+    ui->switchButton->setStyleSheet("background-color: rgba(0, 0, 0, " + settings.value(PCW_SETTING_OPACITY, PCW_SETTING_OPACITY_DEFAULT).toString() + "%); \
      border-style: outset; \
      border-width: 0px; \
      border-radius: 10px; \
-     border-color: rgba(0, 0, 0, " + settings.value(PCW_SETTING_OPACITY).toString() + "%); \
+     border-color: rgba(0, 0, 0, " + settings.value(PCW_SETTING_OPACITY, PCW_SETTING_OPACITY_DEFAULT).toString() + "%); \
      font: bold 14px; \
      min-width: 48px; \
-     width: " + settings.value(PCW_SETTING_WIDTH).toString() + "px; \
-     height: " + settings.value(PCW_SETTING_HEIGHT).toString() + "px; \
+     width: " + settings.value(PCW_SETTING_WIDTH, PCW_SETTING_WIDTH_DEFAULT).toString() + "px; \
+     height: " + settings.value(PCW_SETTING_HEIGHT, PCW_SETTING_HEIGHT_DEFAULT).toString() + "px; \
      padding: 6px;");
     this->refreshIcon();
 }
